import { DomSanitizer, SafeResourceUrl } from '@angular/platform-browser';
import { AppConfiguration } from '.';
import { AuthUser } from './models';
import { Color } from './models/customer/theme/color.interface';
import { ThemeColorType } from './utils';
export interface Theme {
    colors: {
        [colorId: string]: string;
    };
    headerUrl?: SafeResourceUrl;
    footerUrl?: SafeResourceUrl;
    portalUrl?: SafeResourceUrl;
    portalMessage: string;
    portalTitle: string;
}
export declare class ThemeService {
    private domSanitizer;
    get defaultTheme(): Theme;
    set defaultTheme(theme: Theme);
    constructor(domSanitizer: DomSanitizer);
    private baseColors;
    private _defaultTheme;
    defaultMap: {
        [colordId in ThemeColorType]: string;
    };
    applicationColorMap: {
        [colorId: string]: string;
    };
    private _backgroundChoice;
    get backgroundChoice(): Color[];
    getBaseColors(): {
        [colorId in ThemeColorType]?: string;
    };
    getVariationColorsNames(baseName: string): string[];
    init(conf: AppConfiguration, customerColorMap: {
        [colorId: string]: string;
    }): void;
    overloadLocalTheme(colors: {
        [colorId: string]: string;
    }, selectorToOver: string): void;
    getData(authUser: AuthUser, type: string): string | SafeResourceUrl;
    private calculateFontColor;
    private add10Declinations;
    /**
     * Gives complete color theme from current app config and any given customization.
     * Setting base colors (primary, secondary) will return updated variations (primary-light etc..)
     * @param customerColors Entries to override
     */
    getThemeColors(customerColors?: {
        [colorId: string]: string;
    }): {
        [colorId: string]: string;
    };
    overrideTheme(customerThemeMap: any, selector?: string): void;
}
